;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "quick-sdcv" "20250923.1446"
  "Offline dictionary using 'sdcv' (StartDict cli dictionary)."
  '((emacs "25.1"))
  :url "https://github.com/jamescherti/quick-sdcv.el"
  :commit "376d69a914b75091ace06e5b18d777942e66312f"
  :revdesc "376d69a914b7"
  :keywords '("docs" "startdict" "sdcv"))
